.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Contents:

   Overview <self>
   Installation <INSTALLATION>
   Full API Reference <modules>
   Developer Resources <developer_resources>
   Changelog <CHANGELOG>

.. mdinclude:: ../README.md

Specific Doc Pages
==================

.. autosummary::
   :toctree:
   :caption: Important Classes:

   aicsimageio.aics_image.AICSImage
   aicsimageio.readers.reader.Reader
   aicsimageio.readers.ome_tiff_reader.OmeTiffReader
   aicsimageio.readers.tiff_reader.TiffReader
   aicsimageio.writers.ome_tiff_writer.OmeTiffWriter

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
